<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;

class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $row = (int) request('row', 10);

        if ($row < 1 || $row > 100) {
            abort(400, 'The per-page parameter must be an integer between 1 and 100.');
        }

        $customers = Customer::filter(request(['search']))
            ->sortable()
            ->paginate($row)
            ->appends(request()->query());

        return view('customers.index', [
            'customers' => $customers
        ]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('customers.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        dd($request->all());
        $rules = [
            'photo' => 'image|file|max:1024',
            'name' => 'required|string|max:50',
            // 'c_name' => 'required|string|max:50',
            'email' => 'required|email|max:50|unique:customers,email',
            'phone' => 'required|string|max:25|unique:customers,phone',
            'address' => 'required|string|max:150',
        ];

        $validatedData = $request->validate($rules);

        /**
         * Handle upload an image
         */
        $img = $request->file('photo');
        if ($request->hasFile('photo')) {
            $filename = time() . '.' . $img->getClientOriginalExtension();
            @mkdir(public_path('assets/customers/img/'), 0775, true);
            $request->file('photo')->move(public_path('assets/customers/img/'), $filename);
            $validatedData['photo'] = $filename;
        }

        Customer::create($validatedData);

        return Redirect::route('customers.index')->with('success', 'New customer has been created!');
    }

    /**
     * Display the specified resource.
     */
    public function show(Customer $customer)
    {
        abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Customer $customer)
    {
        return view('customers.edit', [
            'customer' => $customer
        ]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Customer $customer)
    {
        $rules = [
            'photo' => 'image|file|max:1024',
            'name' => 'required|string|max:50',
            // 'c_name' => 'required|string|max:50',
            'email' => 'required|email|max:50|unique:customers,email,'.$customer->id,
            'phone' => 'required|string|max:25|unique:customers,phone,'.$customer->id,
            'address' => 'required|string|max:150',
        ];

        $validatedData = $request->validate($rules);

        /**
         * Handle upload image with Storage.
         */
        $img = $request->file('photo');
        if ($request->hasFile('photo')) {
            // Define the directory for images
            $imagePath = public_path('assets/customers/img/');

            // Unlink (delete) the old image if it exists
            if (!empty($customer->photo) && file_exists($imagePath . $customer->photo)) {
                unlink($imagePath . $customer->photo);
            }
            $filename = time() . '.' . $img->getClientOriginalExtension();
            @mkdir(public_path('assets/customers/img/'), 0775, true);
            $request->file('photo')->move($imagePath, $filename);
            $validatedData['photo'] = $filename;
        }

        Customer::where('id', $customer->id)->update($validatedData);

        return Redirect::route('customers.index')->with('success', 'Customer has been updated!');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Customer $customer)
    {
        /**
         * Delete photo if exists.
         */
        if($customer->photo){
            Storage::delete('public/customers/' . $customer->photo);
        }

        Customer::destroy($customer->id);

        return Redirect::route('customers.index')->with('success', 'Customer has been deleted!');
    }
}
