<?php

namespace App\Http\Controllers;

use App\Models\Order;
use Illuminate\Http\Request;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx\Rels;
use Illuminate\Support\Carbon;

class GraphController extends Controller
{
    //
    public function graphEarningReport(Request $request)
    {
        // Validate the input month
        $request->validate(['month' => 'required|string']);

        // Extract month name and convert to month number
        $monthName = $request->month;
        $monthNumber = Carbon::parse($monthName)->month;
        $currentYear = Carbon::now()->year;

        // Initialize an array with 0 for each month
        $monthlyPricesSum = array_fill(1, 12, 0);

        // Query to get the total sum of prices for each month in the specified year
        $prices = Order::selectRaw('MONTH(created_at) as month, SUM(total) as total_price')
            ->where('order_status', 'complete')
            ->whereYear('created_at', $currentYear)
            ->groupByRaw('MONTH(created_at)')
            ->get();

        // Update the monthlyPricesSum array with the actual summed prices
        foreach ($prices as $price) {
            $monthlyPricesSum[$price->month] = (int)$price->total_price;
        }

        // Return the response
        return response()->json([
            'data' => [
                'prices' => array_values($monthlyPricesSum),
                'month' => $monthNumber,
            ]
        ]);
    }

    public function graphMonthReport(Request $request)
    {
        // Validate the input month
        $request->validate(['month' => 'required|string']);

        // Extract month name and convert to month number
        $monthName = $request->month;
        $monthNumber = Carbon::parse($monthName)->month;
        $currentYear = Carbon::now()->year;

        // Initialize an array with 0 for each month
        $monthlyPricesSum = array_fill(1, 12, 0);

        // Query to get the total sum of prices for each month in the specified year
        $prices = Order::selectRaw('MONTH(created_at) as month, SUM(total) as total_price')
            ->where('order_status', 'complete')
            ->whereYear('created_at', $currentYear)
            ->groupByRaw('MONTH(created_at)')
            ->get();

        // Update the monthlyPricesSum array with the actual summed prices
        foreach ($prices as $price) {
            $monthlyPricesSum[$price->month] = (int)$price->total_price;
        }

        // Return the response
        return response()->json([
            'data' => [
                'prices' => array_values($monthlyPricesSum),
                'month' => $monthNumber,
            ]
        ]);
    }
}
