<?php

namespace App\Http\Controllers;

use App\Models\GeneralExp;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;

class general_expController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $row = (int) request('row', 10);

        if ($row < 1 || $row > 100) {
            abort(400, 'The per-page parameter must be an integer between 1 and 100.');
        }

        $expense = GeneralExp::filter(request(['search']))
            ->sortable()
            ->paginate($row)
            ->appends(request()->query());

        return view('general_exp.index', [
            'expense' => $expense
        ]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('general_exp.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $rules = [
            'reason' => 'required|max:150',
            'amount' => 'required|max:150',
            'date' => 'required|max:150',
        ];

        $validatedData = $request->validate($rules);

        GeneralExp::create($validatedData);

        return Redirect::route('general_exp.index')->with('success', 'General Expense has been created!');
    }

    /**
     * Display the specified resource.
     */
    public function show(request $request)
    {
      abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request, $id)
    {
        $general_exp = GeneralExp::find($id);
        return view('general_exp.edit', [
            'general_exp' => $general_exp
        ]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request)
    {
        $rules = [
            'reason' => 'required|max:150',
            'amount' => 'required|max:150',
            'date' => 'required|max:150',
        ];

        $validatedData = $request->validate($rules);

        GeneralExp::where('id', $request->id)->update($validatedData);

        return Redirect::route('general_exp.index')->with('success', 'General Expense has been updated!');
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, $id)
    {
        GeneralExp::destroy($id);
        return Redirect::route('general_exp.index')->with('success', 'General Expense has been deleted!');
    }
}
